@@ -303,7 +303,8 @@ class WebDriver (ElementLocation):
             self.driver=startupOptions['custom_driver']
 
         #Set driver
-        self.driver=driver
+        if self.webdriverName!="custom":
+            self.driver=driver
 
         #Init ElementLocation class
         super().__init__(driver,WebElement)
